<?php
/**
 * The default home page of the plugin. This is like the brains of the operation.
 * It does all the checks and ehos any errors found. It also checks if Multi-Site
 * is already enabled. If it is enabled then it just shows some promotional stuff.
 * 
 * @since 1.0
 * @return null
 */
function multiSiteEnable () {
	global $wpdb, $base;
	// We need to create references to ms global tables to enable Network.
	foreach ( $wpdb->tables ( 'ms_global' ) as $table => $prefixed_table ) {
		$wpdb->$table = $prefixed_table;
	}
	
	// Set no errors to start.
	$there_are_errors = false;
	
	// Include pag header
	include MULTI_SITE_INC_DIR . '/page-head.php';
	
	// Checks if user is super admin
	if ( ! is_super_admin () ) {
		echo '<div class="error">You Are Not Allowed Here! So Get out!</div>';
		include MULTI_SITE_INC_DIR . '/page-footer.php';
		die ( 0 );
	}
	
	// Checks if htaccess file is writable
	if ( ! check_for_htaccess () ) {
		echo '<div class="error"><p>ERROR: This plugin will edit the .htaccess file located in the root folder of your Wordpress installation. Please allow write access to this file and/or directory.</p></div>';
		$there_are_errors = true;
	}
	
	// Checks if config file is writeable
	if ( ! check_for_wp_config () ) {
		echo '<div class="error"><p>ERROR: This plugin will edit the wp-config.php file located in the root folder of your Wordpress installation. Please allow write access to this file and/or directory.</p></div>';
		$there_are_errors = true;
	}
	
	// Die if errors
	if ( $there_are_errors == true ) {
		include MULTI_SITE_INC_DIR . '/page-footer.php';
		die ( 0 );
	}
	
	// Checks if multi-site is already installed.
	if ( enable_multi_site_network_domain_check () ) {
		include MULTI_SITE_INC_DIR . '/give-me-money.inc.php'; // Display new page.
		include MULTI_SITE_INC_DIR . '/page-footer.php';
		die ( 0 );
	} else {
		include MULTI_SITE_INC_DIR . '/page-notice.php'; // Some notices and documentation links.
	}
	
	$base = trailingslashit ( stripslashes ( dirname ( dirname ( $_SERVER ['SCRIPT_NAME'] ) ) ) );
	
	if ( $_POST ) {
		require_once (ABSPATH . 'wp-admin/includes/upgrade.php');
		// create network tables
		install_network ();
		$hostname = enable_multi_site_get_clean_basedomain ();
		$subdomain_install = ! enable_multi_site_allow_subdomain_install () ? false : ( bool ) $_POST ['subdomain_install'];
		if ( ! enable_multi_site_network_domain_check () ) {
			$result = populate_network ( 1, enable_multi_site_get_clean_basedomain (), sanitize_email ( $_POST ['email'] ), stripslashes ( $_POST ['sitename'] ), $base, $subdomain_install );
			if ( is_wp_error ( $result ) ) {
				if ( 1 == count ( $result->get_error_codes () ) && 'no_wildcard_dns' == $result->get_error_code () ) enable_multi_site_network_step2 ( $result );
				else enable_multi_site_network_step1 ( $result );
			} else {
				enable_multi_site_network_step2 ();
			}
		} else {
			enable_multi_site_network_step2 ();
		}
	} elseif ( is_multisite () || enable_multi_site_network_domain_check () ) {
		enable_multi_site_network_step2 ();
	} else {
		enable_multi_site_network_step1 ();
	}
	
	include MULTI_SITE_INC_DIR . '/page-footer.php';
}
?>