<?php

/**
 * Executes all the upgrade functions
 * 
 * @since 1.2
 */

/**
 * Class that holds all the needed update funtions.
 * This was made a class for security and organization purposes.
 */
class enable_multi_site_upgrader {

	/**
	 * Checks current verison of plugin and performs all the patches that need to be done.
	 * Helps prevent doing all of them every time.
	 * 
	 * @since 1.4
	 * @return bool If all the updates were successful or not.
	 */
	public function enable_multi_site_upgrader () {
		$current_version = get_option ( 'enable-multi-site-plugin-version' );
		
		// for right now, just do the upgrade since this is a new method for upgrading.. there is not need to do a bunch of checking
		// TODO: update this for later versions to check versions.
		
		// Check for upgrade to 1.4 from all previous versions
		if ( ($current_version == false ) || ( $current_version < EMS_PLUGIN_VERSION ) ) {
			return $this->upgrade_to_1_4();
		}
	}

	/**
	 * Peforms all the patches to files and folders that have been fixed since
	 * 
	 * @since 1.4
	 * @return bool If it worked or not.
	 */
	private function upgrade_to_1_4 () {
		// First check if the blogs.dir directory exist. Create it otherwise
		echo multi_site_create_blogs_dir ();
		
		// Next fix the .htaccess file errors.
		global $base, $wpdb;
		$hostname = enable_multi_site_get_clean_basedomain ();
		
		// Wildcard DNS message.
		if ( is_wp_error ( $errors ) ) echo '<div class="error">' . $errors->get_error_message () . '</div>';
		
		if ( $_POST ) {
			$subdomain_install = enable_multi_site_allow_subdomain_install () ? (enable_multi_site_allow_subdirectory_install () ? ! empty ( $_POST ['subdomain_install'] ) : true) : false;
		} else {
			if ( is_multisite () ) {
				$subdomain_install = is_subdomain_install ();
			} else {
				$subdomain_install = ( bool ) $wpdb->get_var ( "SELECT meta_value FROM $wpdb->sitemeta WHERE site_id = 1 AND meta_key = 'subdomain_install'" );
			}
		}
				
		// Creates htaccess file
		$htaccess_file = '#Made Multi-Site with Multi-Site Enabler ' . EMS_PLUGIN_VERSION . '#' . "\n";
		$htaccess_file .= 'RewriteEngine On' . "\n";
		$htaccess_file .= 'RewriteBase ' . $base . "\n";
		$htaccess_file .= 'RewriteRule ^index\.php$ - [L]' . "\n";
		$htaccess_file .= "\n";
		$htaccess_file .= '# uploaded files' . "\n";
		$htaccess_file .= 'RewriteRule ^' . ($subdomain_install ? '' : '([_0-9a-zA-Z-]+/)?') . 'files/(.+) wp-includes/ms-files.php?file=$' . ($subdomain_install ? 1 : 2) . ' [L]' . "\n";
		
		if ( ! $subdomain_install ) $htaccess_file .= "\n# add a trailing slash to /wp-admin\n" . 'RewriteRule ^([_0-9a-zA-Z-]+/)?wp-admin$ $1wp-admin/ [R=301,L]' . "\n";
		
		$htaccess_file .= "\r\n" . 'RewriteCond %{REQUEST_FILENAME} -f [OR]' . "\n";
		$htaccess_file .= 'RewriteCond %{REQUEST_FILENAME} -d' . "\n";
		$htaccess_file .= 'RewriteRule ^ - [L]' . "\n";
		
		if ( ! $subdomain_install ) $htaccess_file .= "\nRewriteRule  ^([_0-9a-zA-Z-]+/)?(wp-(content|admin|includes).*) $2 [L]\nRewriteRule  ^([_0-9a-zA-Z-]+/)?(.*\.php)$ $2 [L]";
		
		$htaccess_file .= "\nRewriteRule . index.php [L]";
		
		// Saves the file like Jesus
		if ( check_for_htaccess () ) {
			$myFile = WORDPRESS_ROOT_DIR . '/.htaccess';
			$fh = fopen ( $myFile, 'w' );
			fwrite ( $fh, $htaccess_file );
			fclose ( $fh );
		} else {
			echo '<div class="error"><p>The htaccess file was not updated correctly!</p></div>';
			return false;
		}
		
		// update version table
		update_option ( 'enable-multi-site-plugin-version',  EMS_PLUGIN_VERSION );
		
		return true;
	}
}

// Initate the class
$enable_multi_site_upgrade_class = new enable_multi_site_upgrader();